==> kdevplatform_1.6.0.orig.tar.xz: kdevplatform-1.6.0/plugins/classbrowser/kdevclassbrowser.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-class
Exec=blubb
Comment=This plugin provides a browsable model of the currently parsed classes and other items.
Comment[bg]=Тази приставка дава модел за разглеждане на вече синтактично изгладени класове и други параграфи.
Comment[bs]=Ovaj dodatak omogučava pregledan model trenutno analiziranih klasa i drugih stvari.
Comment[ca]=Aquest connector proporciona un model navegable de les classes analitzades actualment i altres elements.
Comment[ca@valencia]=Este connector proporciona un model navegable de les classes analitzades actualment i altres elements.
Comment[da]=Dette plugin tilbyder en model der kan gennemses for de fortolkede klasser og andre elementer.
Comment[de]=Dieses Modul bietet eine Liste der aktuell eingelesenen Klassen und anderer Elemente.
Comment[el]=Αυτό το πρόσθετο προσφέρει ένα μοντέλο περιήγησης των αναλυμένων κλάσεων και άλλων αντικειμένων.
Comment[en_GB]=This plugin provides a browsable model of the currently parsed classes and other items.
Comment[es]=Este complemento proporciona un modelo navegable de las clases analizadas actualmente y otros elementos.
Comment[et]=See plugin pakub parajasti parsitavate klasside ja teiste elementide sirvitavat mudelit.
Comment[fi]=Tämä liitännäinen tarjoaa selattavan mallin nykyisellään jäsennetyistä luokista ja muista kohteista.
Comment[fr]=Ce module externe fournit un modèle navigable des classes et autres éléments dont l'analyse syntaxique est en cours.
Comment[gl]=Este complemento fornece un modelo navegábel das clases e outros elementos que estean procesados.
Comment[hu]=Ez a bővítmény biztosítja a jelenleg feldolgozott osztályok és egyéb elemek böngészhető modelljét.
Comment[it]=Questa estensione fornisce un modello sfogliabile delle classi attualmente analizzate e altri elementi.
Comment[kk]=Бұл плагині талдау астындағы клас не басқа нысандарыңын шолуға ыңғайлы үлгісін құрып береді.
Comment[nb]=Dette programtillegget gir en modell som det går an å bla i, av de klassene som er tolket og ande elementer.
Comment[nds]=Dit Moduul stellt en dörkiekbor Modell vun de opstunns inleesten Klassen un anner Objekten praat.
Comment[nl]=Deze plugin levert een model om door te bladeren van de nu ontlede klasse's en andere items.
Comment[pl]=Ta wtyczka udostępnia możliwy do przeglądania model przeanalizowanych klas i innych elementów.
Comment[pt]=Este 'plugin' oferece um modelo navegável pelas classes e outros itens processados neste momento.
Comment[pt_BR]=Este plugin fornece um modelo navegável das classes atualmente analisadas e outros itens.
Comment[ru]=Это расширение предоставляет просматриваемую модель разобранных на текущий момент классов и других элементов.
Comment[sk]=Tento plugin poskytuje prehliadateľný model aktuálne analyzovanej triedy a iných položiek.
Comment[sl]=Vstavek prinaša model trenutno razčlenjenih razredov in drugih predmetov, po katerih je moč brskati.
Comment[sv]=Insticksprogrammet tillhandahåller en bläddringsbar modell av klasser och andra objekt som för närvarande har tolkats.
Comment[tr]=Bu eklenti ayrıştırılmış sınıflar ve diğer ögeler için göz atmaya uygun bir model sağlar.
Comment[ug]=بۇ قىستۇرما نۆۋەتتە تەھىل قىلىنغان تىپ ۋە باشقا تۈرلەرنىڭ كۆرۈنۈشچان مودېلىنى تەمىنلەيدۇ
Comment[uk]=За допомогою цього додатка можна створити придатну для перегляду модель класів та інших елементів, над якими ви працюєте.
Comment[x-test]=xxThis plugin provides a browsable model of the currently parsed classes and other items.xx
Comment[zh_CN]=此插件提供了一个当前已分析类和其它项目的可视化模型。
Comment[zh_TW]=此外掛程式提供一個可瀏覽目前已分析的類別與其他項目的模組。
Name=Class Browser
Name[bg]=Браузър за класове
Name[bs]=Pregledač klasa
Name[ca]=Navegador de classes
Name[ca@valencia]=Navegador de classes
Name[cs]=Prohlížeč tříd
Name[da]=Klassebrowser
Name[de]=Klassen-Browser
Name[el]=Περιηγητής κλάσεων
Name[en_GB]=Class Browser
Name[es]=Navegador de clases
Name[et]=Klassibrauser
Name[fi]=Luokkaselain
Name[fr]=Navigateur de classes
Name[gl]=Navegador de clases
Name[hu]=Osztályböngésző
Name[it]=Browser classi
Name[ja]=クラスブラウザ
Name[kk]=Класс шолғышы
Name[nb]=Klasseleser
Name[nds]=Klassenkieker
Name[nl]=Klassebrowser
Name[pl]=Przeglądarka klas
Name[pt]=Navegador de Classes
Name[pt_BR]=Navegador de Classes
Name[ru]=Дерево классов
Name[sk]=Prehliadač tried
Name[sl]=Brskalnik po razredih
Name[sv]=Klassbläddrare
Name[tr]=Sınıf Tarayıcı
Name[ug]=تىپ كۆرگۈ
Name[uk]=Переглядач класів
Name[x-test]=xxClass Browserxx
Name[zh_CN]=类浏览器
Name[zh_TW]=類別瀏覽器
GenericName=Class Browser
GenericName[bg]=Браузър за класове
GenericName[bs]=Pregledač klasa
GenericName[ca]=Navegador de classes
GenericName[ca@valencia]=Navegador de classes
GenericName[cs]=Prohlížeč tříd
GenericName[da]=Klassebrowser
GenericName[de]=Klassen-Browser
GenericName[el]=Περιηγητής κλάσεων
GenericName[en_GB]=Class Browser
GenericName[es]=Navegador de clases
GenericName[et]=Klassibrauser
GenericName[fi]=Luokkaselain
GenericName[fr]=Navigateur de classes
GenericName[gl]=Navegador de clases
GenericName[hu]=Osztályböngésző
GenericName[it]=Browser classi
GenericName[ja]=クラスブラウザ
GenericName[kk]=Класс шолғышы
GenericName[lv]=Klašu pārlūks
GenericName[nb]=Klasseleser
GenericName[nds]=Klassenkieker
GenericName[nl]=Klassebrowser
GenericName[pa]=ਕਲਾਸ ਬਰਾਊਜ਼ਰ
GenericName[pl]=Przeglądarka klas
GenericName[pt]=Navegador de Classes
GenericName[pt_BR]=Navegador de classes
GenericName[ro]=Navigator de clase
GenericName[ru]=Дерево классов
GenericName[sk]=Prehliadač tried
GenericName[sl]=Brskalnik po razredih
GenericName[sv]=Klassbläddrare
GenericName[tr]=Sınıf Tarayıcı
GenericName[ug]=تىپ كۆرگۈ
GenericName[uk]=Переглядач класів
GenericName[x-test]=xxClass Browserxx
GenericName[zh_CN]=类浏览器
GenericName[zh_TW]=類別瀏覽器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevclassbrowser
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevclassbrowser
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Mode=GUI

==> kdevplatform-1.6.90.tar.xz: kdevplatform-1.6.90/plugins/classbrowser/kdevclassbrowser.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=code-class
Exec=blubb
Comment=This plugin provides a browsable model of the currently parsed classes and other items.
Comment[bg]=Тази приставка дава модел за разглеждане на вече синтактично изгладени класове и други параграфи.
Comment[bs]=Ovaj dodatak omogučava pregledan model trenutno analiziranih klasa i drugih stvari.
Comment[ca]=Aquest connector proporciona un model navegable de les classes analitzades actualment i altres elements.
Comment[ca@valencia]=Este connector proporciona un model navegable de les classes analitzades actualment i altres elements.
Comment[da]=Dette plugin tilbyder en model der kan gennemses for de fortolkede klasser og andre elementer.
Comment[de]=Dieses Modul bietet eine Liste der aktuell eingelesenen Klassen und anderer Elemente.
Comment[el]=Αυτό το πρόσθετο προσφέρει ένα μοντέλο περιήγησης των αναλυμένων κλάσεων και άλλων αντικειμένων.
Comment[en_GB]=This plugin provides a browsable model of the currently parsed classes and other items.
Comment[es]=Este complemento proporciona un modelo navegable de las clases analizadas actualmente y otros elementos.
Comment[et]=See plugin pakub parajasti parsitavate klasside ja teiste elementide sirvitavat mudelit.
Comment[fi]=Tämä liitännäinen tarjoaa selattavan mallin nykyisellään jäsennetyistä luokista ja muista kohteista.
Comment[fr]=Ce module externe fournit un modèle navigable des classes et autres éléments dont l'analyse syntaxique est en cours.
Comment[gl]=Este complemento fornece un modelo navegábel das clases e outros elementos que estean procesados.
Comment[hu]=Ez a bővítmény biztosítja a jelenleg feldolgozott osztályok és egyéb elemek böngészhető modelljét.
Comment[it]=Questa estensione fornisce un modello sfogliabile delle classi attualmente analizzate e altri elementi.
Comment[kk]=Бұл плагині талдау астындағы клас не басқа нысандарыңын шолуға ыңғайлы үлгісін құрып береді.
Comment[nb]=Dette programtillegget gir en modell som det går an å bla i, av de klassene som er tolket og ande elementer.
Comment[nds]=Dit Moduul stellt en dörkiekbor Modell vun de opstunns inleesten Klassen un anner Objekten praat.
Comment[nl]=Deze plugin levert een model om door te bladeren van de nu ontlede klasse's en andere items.
Comment[pl]=Ta wtyczka udostępnia możliwy do przeglądania model przeanalizowanych klas i innych elementów.
Comment[pt]=Este 'plugin' oferece um modelo navegável pelas classes e outros itens processados neste momento.
Comment[pt_BR]=Este plugin fornece um modelo navegável das classes atualmente analisadas e outros itens.
Comment[ru]=Это расширение предоставляет просматриваемую модель разобранных на текущий момент классов и других элементов.
Comment[sk]=Tento plugin poskytuje prehliadateľný model aktuálne analyzovanej triedy a iných položiek.
Comment[sl]=Vstavek prinaša model trenutno razčlenjenih razredov in drugih predmetov, po katerih je moč brskati.
Comment[sv]=Insticksprogrammet tillhandahåller en bläddringsbar modell av klasser och andra objekt som för närvarande har tolkats.
Comment[tr]=Bu eklenti ayrıştırılmış sınıflar ve diğer ögeler için göz atmaya uygun bir model sağlar.
Comment[ug]=بۇ قىستۇرما نۆۋەتتە تەھىل قىلىنغان تىپ ۋە باشقا تۈرلەرنىڭ كۆرۈنۈشچان مودېلىنى تەمىنلەيدۇ
Comment[uk]=За допомогою цього додатка можна створити придатну для перегляду модель класів та інших елементів, над якими ви працюєте.
Comment[x-test]=xxThis plugin provides a browsable model of the currently parsed classes and other items.xx
Comment[zh_CN]=此插件提供了一个当前已分析类和其它项目的可浏览化视窗模型。
Comment[zh_TW]=此外掛程式提供一個可瀏覽目前已分析的類別與其他項目的模組。
Name=Class Browser
Name[bg]=Браузър за класове
Name[bs]=Pregledač klasa
Name[ca]=Navegador de classes
Name[ca@valencia]=Navegador de classes
Name[cs]=Prohlížeč tříd
Name[da]=Klassebrowser
Name[de]=Klassen-Browser
Name[el]=Περιηγητής κλάσεων
Name[en_GB]=Class Browser
Name[es]=Navegador de clases
Name[et]=Klassibrauser
Name[fi]=Luokkaselain
Name[fr]=Navigateur de classes
Name[gl]=Navegador de clases
Name[hu]=Osztályböngésző
Name[it]=Browser classi
Name[ja]=クラスブラウザ
Name[kk]=Класс шолғышы
Name[nb]=Klasseleser
Name[nds]=Klassenkieker
Name[nl]=Klassebrowser
Name[pl]=Przeglądarka klas
Name[pt]=Navegador de Classes
Name[pt_BR]=Navegador de Classes
Name[ru]=Дерево классов
Name[sk]=Prehliadač tried
Name[sl]=Brskalnik po razredih
Name[sv]=Klassbläddrare
Name[tr]=Sınıf Tarayıcı
Name[ug]=تىپ كۆرگۈ
Name[uk]=Переглядач класів
Name[x-test]=xxClass Browserxx
Name[zh_CN]=类浏览器
Name[zh_TW]=類別瀏覽器
GenericName=Class Browser
GenericName[bg]=Браузър за класове
GenericName[bs]=Pregledač klasa
GenericName[ca]=Navegador de classes
GenericName[ca@valencia]=Navegador de classes
GenericName[cs]=Prohlížeč tříd
GenericName[da]=Klassebrowser
GenericName[de]=Klassen-Browser
GenericName[el]=Περιηγητής κλάσεων
GenericName[en_GB]=Class Browser
GenericName[es]=Navegador de clases
GenericName[et]=Klassibrauser
GenericName[fi]=Luokkaselain
GenericName[fr]=Navigateur de classes
GenericName[gl]=Navegador de clases
GenericName[hu]=Osztályböngésző
GenericName[it]=Browser classi
GenericName[ja]=クラスブラウザ
GenericName[kk]=Класс шолғышы
GenericName[lv]=Klašu pārlūks
GenericName[nb]=Klasseleser
GenericName[nds]=Klassenkieker
GenericName[nl]=Klassebrowser
GenericName[pa]=ਕਲਾਸ ਬਰਾਊਜ਼ਰ
GenericName[pl]=Przeglądarka klas
GenericName[pt]=Navegador de Classes
GenericName[pt_BR]=Navegador de classes
GenericName[ro]=Navigator de clase
GenericName[ru]=Дерево классов
GenericName[sk]=Prehliadač tried
GenericName[sl]=Brskalnik po razredih
GenericName[sv]=Klassbläddrare
GenericName[tr]=Sınıf Tarayıcı
GenericName[ug]=تىپ كۆرگۈ
GenericName[uk]=Переглядач класів
GenericName[x-test]=xxClass Browserxx
GenericName[zh_CN]=类浏览器
GenericName[zh_TW]=類別瀏覽器
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevclassbrowser
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevclassbrowser
X-KDE-PluginInfo-Author=Hamish Rodda
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Mode=GUI
